@@ -208,13 +208,13 @@ class BloggingTestCase(BaseTestCase):
 
         response = requests.put(self.base_url, params=params)
         response.connection.close()
-        # now, listing it
-        params = {'order_by': 'title'}
+        # now, listing it in reverse order by title
+        params = {'order_by': '-title'}
         response = requests.get(self.base_url + 'list', params=params)
         response.connection.close()
-        last_title = response.json()['items'][-1]['title']
+        first_post = response.json()['items'][0]['title']
 
-        self.assertEqual(last_title, 'zx post test the last')
+        self.assertEqual(first_post, 'zx post test the last')
 
     def test_comment_on_post(self):
         parent_id = self.posts[0].id
