@@ -263,7 +263,7 @@ class RestHandler(BaseRequestHandler):
 
         objects = self.model.objects.filter(**clean_kwargs)
         for order in self.order_by:
-            objects.order_by(order.decode())
+            objects = objects.order_by(order.decode())
 
         total_items = len(objects)
         extra = {'total_items': total_items}
